@@ -1,6 +1,6 @@
-/* psync.h - Last modified: 28-Mar-2019 (kobayasy)
+/* psync.h - Last modified: 27-Feb-2020 (kobayasy)
  *
- * Copyright (c) 2018-2019 by Yuichi Kobayashi <kobayasy@kobayasy.com>
+ * Copyright (c) 2018-2020 by Yuichi Kobayashi <kobayasy@kobayasy.com>
  *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation files
@@ -27,9 +27,10 @@
 #define _INCLUDE_psync_h
 
 #include <signal.h>
-#include <stdbool.h>
 #include <time.h>
 
+#define PSYNC_FILEID 0x01665370  /* 'p', 'S', 'f', 1 */
+
 //#define ERROR_UNKNOWN  (-1)
 #define ERROR_FTYPE    (-2)
 #define ERROR_FPERM    (-3)
